pub fn create_solana_tools(agent: SolanaAgentKit) -> ToolSetExpand description
An function to build a set of tools that can be used with Solana.
DeployCollection: Tool to deploy a new NFT collection on Solana blockchain.DeployToken: Tool to deploy a new token on Solana blockchain.FetchPrice: Tool to fetch the price of a given token in USDC.GetBalance: Tool to get the balance of a specified wallet.GetBalanceOther: Tool to get the balance of another wallet.GetTps: Tool to get the current TPS of the Solana network.GetWalletAddress: Tool to the wallet address of the agent.LaunchPumpfunToken: Tool to launch a token on Pump.fun.MintNFT: Tool to mint a new NFT in a collection on Solana blockchain.FetchPricePyTh: Tool to fetch the price of a given price feed from Pyth’s Hermes service.RequestFaucetFunds: Tool to request funds from a faucet.StakeWithJup: Tool to stake your SOL (Solana), also called as SOL staking or liquid staking.Trade: Tool to swap tokens to another token ( It uses Jupiter Exchange ).Transfer: Tool to transfer tokens or SOL to another address ( also called as wallet address ).FetchTokenReportSummary: Tool to fetch a summary report for a specific token from RugCheck.FetchTokenReportDetailed: Tool to fetch a detailed report for a specific token from RugCheck.CreateGibworkTask: Tool to create a task on Gibwork.CloseEmptyTokenAccounts: Tool to close empty SPL Token accounts associated with your wallet to reclaim rent.StakeWithSolayer: Tool to stake native SOL with Solayer’s restaking protocol to receive Solayer SOL (sSOL).GetTokenData: Tool to get the token data for a given token mint address.CreateWebHook: Tool to creates a new webhook in the Helius system to monitor transactions for specified account addresses.DeleteWebhook: Tool to deletes a Helius webhook by its unique ID.GetWebHook: Tool to retrieves details of a Helius webhook by its unique ID.TransactionParse: Tool to parse a Solana transaction to retrieve detailed information using the Helius Enhanced Transactions API.